@@ -525,16 +525,15 @@ class DictProxyField(object):
             return self
         if getattr(obj, self._fld_name) is None:
             return
-        return dict([(self._key_type(k), v)
-                     for k, v in six.iteritems(getattr(obj, self._fld_name))])
+        return {self._key_type(k): v
+                for k, v in six.iteritems(getattr(obj, self._fld_name))}
 
     def __set__(self, obj, val):
         if val is None:
             setattr(obj, self._fld_name, val)
         else:
             setattr(obj, self._fld_name,
-                    dict([(six.text_type(k), v)
-                          for k, v in six.iteritems(val)]))
+                    {six.text_type(k): v for k, v in six.iteritems(val)})
 
 
 class Set(CompoundFieldType):
